@@ -5,6 +5,9 @@ DialCancelDlg::DialCancelDlg (const QString &strNum, QWidget *parent)
 : QMessageBox (parent)
 , strContact (strNum)
 {
+    OsDependent &osd = Singletons::getRef().getOSD ();
+    osd.setDefaultWindowAttributes (this);
+
     this->setText (QString("Dialing %1. Abort / Cancel ends the call")
                    .arg(strContact));
     this->setStandardButtons (QMessageBox::Ok | QMessageBox::Abort);
@@ -19,8 +22,6 @@ DialCancelDlg::doModal (const QString &strMyNumber)
 
     int rv = this->exec ();
 
-    obsF.stopObservers ();
-
     return (rv);
 }//DialCancelDlg::doModal
 
@@ -29,3 +30,23 @@ DialCancelDlg::callStarted ()
 {
     this->done (QMessageBox::Ok);
 }//DialCancelDlg::callStarted
+
+void
+DialCancelDlg::doNonModal (const QString &strMyNumber)
+{
+    ObserverFactory &obsF = Singletons::getRef().getObserverFactory ();
+    obsF.startObservers (strMyNumber, this, SLOT (callStarted()));
+
+    this->show ();
+}//DialCancelDlg::doNonModal
+
+void
+DialCancelDlg::done (int r)
+{
+    ObserverFactory &obsF = Singletons::getRef().getObserverFactory ();
+    obsF.stopObservers ();
+
+    emit dialDlgDone (r, strContact);
+
+    QMessageBox::done (r);
+}//DialCancelDlg::done
